@@ -4,7 +4,7 @@ use warnings;
 use 5.006;
 use base 'Exporter';
 
-our $VERSION = '0.26';
+our $VERSION = '0.27';
 
 use Carp 'confess';
 use Scalar::Util 'blessed';
@@ -268,16 +268,19 @@ Mouse - Moose minus the antlers
 
 L<Moose> is wonderful. B<Use Moose instead of Mouse.>
 
-Unfortunately, Moose has a compile-time penalty. Though significant progress has
-been made over the years, the compile time penalty is a non-starter for some
-applications.
+Unfortunately, Moose has a compile-time penalty. Though significant progress
+has been made over the years, the compile time penalty is a non-starter for
+some very specific applications. If you are writing a command-line application
+or CGI script where startup time is essential, you may not be able to use
+Moose. We recommend that you instead use L<HTTP::Engine> and FastCGI for the
+latter, if possible.
 
 Mouse aims to alleviate this by providing a subset of Moose's functionality,
 faster.
 
 We're also going as light on dependencies as possible.
-L<Class::Method::Modifiers> or L<Data::Util> is required if you want support
-for L</before>, L</after>, and L</around>.
+L<Class::Method::Modifiers::Fast> or L<Class::Method::Modifiers> is required
+if you want support for L</before>, L</after>, and L</around>.
 
 =head2 MOOSE COMPAT
 
@@ -289,7 +292,13 @@ runs the test suite 4x faster.
 The idea is that, if you need the extra power, you should be able to run
 C<s/Mouse/Moose/g> on your codebase and have nothing break. To that end,
 we have written L<Any::Moose> which will act as Mouse unless Moose is loaded,
-in which case it will act as Moose.
+in which case it will act as Moose. Since Mouse is a little sloppier than
+Moose, if you run into weird errors, it would be worth running:
+
+    ANY_MOOSE=Moose perl your-script.pl
+
+to see if the bug is caused by Mouse. Moose's diagnostics and validation are
+also much better.
 
 =head2 MouseX
 
@@ -299,6 +308,12 @@ should upgrade to Moose. We don't need two parallel sets of extensions!
 If you really must write a Mouse extension, please contact the Moose mailing
 list or #moose on IRC beforehand.
 
+=head2 Maintenance
+
+The original author of this module has mostly stepped down from maintaining
+Mouse. See L<http://www.nntp.perl.org/group/perl.moose/2009/04/msg653.html>.
+If you would like to help maintain this module, please get in touch with us.
+
 =head1 KEYWORDS
 
 =head2 meta -> Mouse::Meta::Class
@@ -495,7 +510,9 @@ L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Mouse>.
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2008 Shawn M Moore.
+Copyright 2008-2009 Infinity Interactive, Inc.
+
+http://www.iinteractive.com/
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
